# Orpheus
A machine learning-based search engine that takes in a short symbolic musical phrase and retrieves the song the phrase is from.

We will be using heuristic measures extracted from musical sequences as well as features provided by deep neural nets to 
arrive at a holistic ranking that considers many different factors. 

The database will be built from symbolic encodings(MIDI) of classical music. We will also be looking into searching over
other datasets that have very good symbolic datasets such as the Nottingham dataset.



# Who is Orpheus?

Orpheus with his lute made trees,  
And the mountain tops that freeze,  
Bow themselves when he did sing:  
To his music plants and flowers  
Ever sprung; as sun and showers  
There had made a lasting spring.  
Every thing that heard him play,  
Even the billows of the sea,  
Hung their heads, and then lay by.  
In sweet music is such art,  
Killing care and grief of heart  
Fall asleep, or hearing, die.

\- Bill
